@@ -1,5 +1,9 @@
-from typing import Optional
+from __future__ import annotations
 from .data_stag_common import StagDataTypes
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from scistag.datastag.data_stag_vault import DataStagVault
 
 
 class DataStagElement:
@@ -14,14 +18,18 @@ class DataStagElement:
         :param vault: The vault in which the element is stored
         """
         self.data = None
-        self.vault: 'DataStagVault' = vault  # The element's vault
+        self.vault: DataStagVault = vault  # The element's vault
         self.simple = True  # Simple data type?
-        self.name: Optional[str] = None  # The element's name
-        self.parent: Optional["DataStagElement"] = None  # The parent element (e.g. a list containing the element)
-        self.deprecation_time: Optional[float] = None  # Time when this element shall be destroyed
-        self.version_counter: int = 0  # The element's update counter
+        self.name: str | None = None  # The element's name
+        self.parent: DataStagElement | None = None
+        "The parent element (e.g. a list containing the element)"
+        self.deprecation_time: float | None = None
+        "Time when this element shall be destroyed"
+        self.version_counter: int = 0
+        "The element's update counter"
 
-    def set_value(self, value: StagDataTypes, deprecation_time: Optional[float] = None):
+    def set_value(self, value: StagDataTypes,
+                  deprecation_time: float | None = None):
         """
         Sets the element's new value
 
