@@ -1,4 +1,4 @@
-from typing import Optional, Dict, List, Union
+from __future__ import annotations
 import time
 import fnmatch
 from collections import defaultdict
@@ -13,9 +13,10 @@ class DataStagVault:
     The root access point to a DataStag
     """
 
-    FOLDER_SEPARATOR = "."  # The sign which defines in which folder a key is located
+    FOLDER_SEPARATOR = "."
+    "The sign which defines in which folder a key is located"
 
-    local_vault: "DataStagVault" = None  # The local vault instance
+    local_vault: DataStagVault = None  # The local vault instance
 
     def __init__(self):
         """
@@ -24,11 +25,12 @@ class DataStagVault:
         self.lock = RLock()
         self.start_time: int = int(time.time())
         self.last_garbage_collection_time = self.start_time - 1
-        self.deprecating_elements: Dict[int, List[DataStagElement]] = defaultdict(list)
+        self.deprecating_elements: dict[int, list[DataStagElement]] = \
+            defaultdict(list)
         self.deprecation_stepping = 0
-        self.global_dictionary: Dict[str, DataStagElement] = {}
+        self.global_dictionary: dict[str, DataStagElement] = {}
         "A dictionary containing all elements"
-        self.folders: Dict[str, dict] = defaultdict(dict)
+        self.folders: dict[str, dict] = defaultdict(dict)
         "A folder based more fine grained search index"
 
     @classmethod
@@ -46,7 +48,8 @@ class DataStagVault:
         """
         return time.time()
 
-    def push(self, name: str, data: List[StagDataTypes], timeout_s: Optional[float] = None, index=-1) -> int:
+    def push(self, name: str, data: list[StagDataTypes],
+             timeout_s: float | None = None, index=-1) -> int:
         """
         Appends an element at the end of a list
         :param name: The element's name
@@ -57,7 +60,7 @@ class DataStagVault:
         """
         self.collect_garbage()
         with self.lock:
-            list_handle: Optional[DataStagList] = self._get_list_instance(name)
+            list_handle: DataStagList | None = self._get_list_instance(name)
             if list_handle is None:
                 assert not self.exists(name)
                 list_handle = DataStagList(vault=self)
@@ -71,9 +74,11 @@ class DataStagVault:
                     self._update_deprecating_element(element, dep_time)
                 element.set_value(value, dep_time)
                 element_list.append(element)
-            return list_handle.add_elements(element_list, index=index, deprecation_time=dep_time)
+            return list_handle.add_elements(element_list, index=index,
+                                            deprecation_time=dep_time)
 
-    def pop(self, name: str, default: StagDataReturnTypes = None, index: int = 0) -> StagDataReturnTypes:
+    def pop(self, name: str, default: StagDataReturnTypes = None,
+            index: int = 0) -> StagDataReturnTypes:
         """
         Tries to remove an element at the beginning of a list
         :param name: The name's list
@@ -82,18 +87,20 @@ class DataStagVault:
         :return: The element which was removed
         """
         with self.lock:
-            list_handle: Optional[DataStagList] = self._get_list_instance(name)
+            list_handle: DataStagList | None = self._get_list_instance(name)
             if list_handle is None:
                 return default
             uptime = self.get_server_up_time() if list_handle.objects_with_timeout else None
-            element = list_handle.pop_element(index=index, deprecation_time=uptime)
+            element = list_handle.pop_element(index=index,
+                                              deprecation_time=uptime)
             if len(list_handle.list_elements) == 0:
                 self.delete(name)
             if element is None:
                 return default
             return element.get_value()
 
-    def set(self, name: str, data: StagDataTypes, timeout_s: Optional[float] = None) -> bool:
+    def set(self, name: str, data: StagDataTypes,
+            timeout_s: float | None = None) -> bool:
         """
         Stores a named element in the database
         :param name: The element's name
@@ -117,8 +124,9 @@ class DataStagVault:
                 element.set_value(data)
             return True
 
-    def add(self, name: str, value: Union[float, int] = 1, timeout_s: Optional[float] = None, default=0) -> \
-            Union[float, int]:
+    def add(self, name: str, value: float | int = 1,
+            timeout_s: float | None = None, default=0) -> \
+            float | int:
         """
         Adds given value to the element stored in the database. If it does not exist yet, it will be initialized
         with default.
@@ -138,7 +146,8 @@ class DataStagVault:
             self.set(name, new_value)
             return new_value
 
-    def get(self, name: str, default: StagDataReturnTypes = None) -> StagDataReturnTypes:
+    def get(self, name: str,
+            default: StagDataReturnTypes = None) -> StagDataReturnTypes:
         """
         Tries to read an element from the database
         :param name: The element's name
@@ -155,7 +164,8 @@ class DataStagVault:
                     return None
             return element.get_value()
 
-    def get_ex(self, name: str, default: StagDataReturnTypes = None, version_counter=-1) -> (int, StagDataReturnTypes):
+    def get_ex(self, name: str, default: StagDataReturnTypes = None,
+               version_counter=-1) -> (int, StagDataReturnTypes):
         """
         Tries to read an element from the database. Allows to add a version check so only data will be returned if
         it changed since the last get_ex.
@@ -177,7 +187,8 @@ class DataStagVault:
                 return version_counter, None
             return element.version_counter, element.get_value()
 
-    def find(self, mask: str, limit: int = 100, relative_names: bool = False, recursive: bool = False):
+    def find(self, mask: str, limit: int = 100, relative_names: bool = False,
+             recursive: bool = False):
         """
         Finds a list of elements by name
         :param mask: The search mask. If it contains a folder the mask is only applied to the nested element
@@ -194,15 +205,21 @@ class DataStagVault:
             folder = self.folders[folder_name]
             key_list = list(folder.keys())
             key_list = fnmatch.filter(key_list, rel_name)
-            global_key_list = [self._get_global_name(folder_name, key) for key in key_list]
+            global_key_list = [self._get_global_name(folder_name, key) for key
+                               in key_list]
             if not relative_names:
                 key_list = global_key_list
-                key_list = [key for key in key_list if self.global_dictionary[key].deprecation_time is None or
-                            self.global_dictionary[key].deprecation_time > uptime]
+                key_list = [key for key in key_list if self.global_dictionary[
+                    key].deprecation_time is None or
+                            self.global_dictionary[
+                                key].deprecation_time > uptime]
             else:
-                key_list = [key for key, g_key in zip(key_list, global_key_list) if
-                            self.global_dictionary[g_key].deprecation_time is None or
-                            self.global_dictionary[g_key].deprecation_time > uptime]
+                key_list = [key for key, g_key in zip(key_list, global_key_list)
+                            if
+                            self.global_dictionary[
+                                g_key].deprecation_time is None or
+                            self.global_dictionary[
+                                g_key].deprecation_time > uptime]
             if limit != -1 and len(key_list) > limit:
                 key_list = key_list[0:limit]
             if recursive:
@@ -210,7 +227,8 @@ class DataStagVault:
                 for cur_sub_folder in sub_folders:
                     new_keys = self.find(cur_sub_folder + ".*", recursive=False)
                     if relative_names:
-                        new_keys = [key[len(folder_name) + 1:] for key in new_keys]
+                        new_keys = [key[len(folder_name) + 1:] for key in
+                                    new_keys]
                         key_list += new_keys
                     else:
                         key_list += new_keys
@@ -236,7 +254,8 @@ class DataStagVault:
                             sub_folder_set.append(element)
         return list(sub_folder_set)
 
-    def get_values_by_name(self, mask: str, limit: int = 100, flat: bool = True):
+    def get_values_by_name(self, mask: str, limit: int = 100,
+                           flat: bool = True):
         """
         Returns the data of a set of elements by name.
         :param mask: The search mask. If it contains a folder the mask is only applied to the nested element
@@ -247,10 +266,13 @@ class DataStagVault:
         with self.lock:
             names = self.find(mask, limit)
             if flat:
-                results = [self.global_dictionary[name].get_value() for name in names if
+                results = [self.global_dictionary[name].get_value() for name in
+                           names if
                            self.global_dictionary[name].simple]
             else:
-                results = [{"name": name, "value": self.global_dictionary[name].get_value()} for name in names if
+                results = [{"name": name,
+                            "value": self.global_dictionary[name].get_value()}
+                           for name in names if
                            self.global_dictionary[name].simple]
             return results
 
@@ -262,7 +284,7 @@ class DataStagVault:
         :return: The list length's if it does exist. Otherwise 0.
         """
         with self.lock:
-            list_handle: Optional[DataStagList] = self._get_list_instance(name)
+            list_handle: DataStagList | None = self._get_list_instance(name)
             if list_handle is None:
                 return 0
             if list_handle.objects_with_timeout:
@@ -272,7 +294,8 @@ class DataStagVault:
                 return 0
             return len(list_handle.list_elements)
 
-    def lelements(self, name: str, start: int, end: Optional[int]) -> List[StagDataTypes]:
+    def lelements(self, name: str, start: int, end: int | None) -> list[
+        StagDataTypes]:
         """
         Tries to receive a list of elements from the vault
 
@@ -310,7 +333,8 @@ class DataStagVault:
         """
         return self._delete_element(name)
 
-    def delete_multiple(self, search_masks: List[str], recursive: bool = False) -> int:
+    def delete_multiple(self, search_masks: list[str],
+                        recursive: bool = False) -> int:
         """
         Deletes a set of elements.
         :param search_masks: The element's names or search masks. May not point directly to the root directory
@@ -320,7 +344,8 @@ class DataStagVault:
         with self.lock:
             total = 0
             for cur_mask in search_masks:
-                if len(cur_mask) == 0 or cur_mask[0] == "*" or "." not in cur_mask:
+                if len(cur_mask) == 0 or cur_mask[
+                    0] == "*" or "." not in cur_mask:
                     continue
                 elements = self.find(cur_mask, recursive=recursive)
                 for cur_element in elements:
@@ -328,12 +353,15 @@ class DataStagVault:
                         total += 1
         return total
 
-    def _get_element_by_name(self, name: str, deprecation_time: Optional[float] = None) -> Optional[DataStagElement]:
+    def _get_element_by_name(self, name: str,
+                             deprecation_time: float | None = None) -> \
+            DataStagElement | None:
         """
         Tries to retrieve a database element
 
         :param name: The element's name
-        :param deprecation_time: The server uptime in seconds. If provided the element will be deleted if it timed out.
+        :param deprecation_time: The server uptime in seconds. If provided the
+            element will be deleted if it timed out.
         """
         element = self.global_dictionary.get(name, None)
         if element is None:
@@ -346,12 +374,12 @@ class DataStagVault:
                 return None
         return element
 
-    def _get_list_instance(self, name: str) -> Optional[DataStagList]:
+    def _get_list_instance(self, name: str) -> DataStagList | None:
         """
         Tries to retrieve the element of the type list
+
         :param name: The element's name
         :return:
-        :
         """
         element = self._get_element_by_name(name)
         if isinstance(element, DataStagList):
@@ -361,6 +389,7 @@ class DataStagVault:
     def _get_folder(self, name: str) -> str:
         """
         Returns the element's folder name defined by slashes
+
         :param name: The elements name
         :return: The folder, "" if none
         """
@@ -373,6 +402,7 @@ class DataStagVault:
     def _split_folder_and_name(self, name: str) -> (str, str):
         """
         Returns the element's folder name defined by slashes
+
         :param name: The elements name
         :return: The folder and file name
         """
@@ -421,6 +451,7 @@ class DataStagVault:
     def _get_round_deprecation_time(self, dep_time: float):
         """
         Returns the deprecation time rounded up to the next second as integer
+
         :param dep_time: The deprecation time
         :return: Deprecation time in seconds
         """
@@ -428,12 +459,15 @@ class DataStagVault:
 
     def _remove_from_deprecation_list(self, element: DataStagElement):
         """
-        Checks whether the element was already in a deprecation list and removes if from that one
+        Checks whether the element was already in a deprecation list and removes
+        if from that one
+
         :param element: The element
         :return: True if the element was already existing and had to be removed
         """
         if element.deprecation_time is not None:
-            prev_dep_time_round = self._get_round_deprecation_time(element.deprecation_time)
+            prev_dep_time_round = self._get_round_deprecation_time(
+                element.deprecation_time)
             prev_list = self.deprecating_elements[prev_dep_time_round]
             if element in prev_list:
                 prev_list.remove(element)
@@ -442,9 +476,12 @@ class DataStagVault:
                     return True
         return False
 
-    def _update_deprecating_element(self, element: DataStagElement, dep_time: float = None):
+    def _update_deprecating_element(self, element: DataStagElement,
+                                    dep_time: float = None):
         """
-        Registers the element in the deprecation registry so it can automatically be destroyed once it's outdated
+        Registers the element in the deprecation registry so it can
+        automatically be destroyed once it's outdated
+
         :param element: The element
         :param dep_time: The element's new deprecation time
         """
@@ -484,8 +521,10 @@ class DataStagVault:
                     else:
                         raise Exception("Element has neither name mor parent")
                     elements = self.deprecating_elements[cur_time_offset]
-                if cur_time_offset in self.deprecating_elements:  # in case the list did not empty itself yet
-                    del self.deprecating_elements[cur_time_offset]  # delete key
+                if cur_time_offset in self.deprecating_elements:
+                    # in case the list did not empty itself yet
+                    del self.deprecating_elements[cur_time_offset]
+                    # delete key
         return True
 
     def get_status(self, advanced: bool = False):
@@ -504,8 +543,10 @@ class DataStagVault:
                     "totalUpTime": time.time() - self.start_time
                 }
             if advanced:
-                result['deprecationGroupNames'] = list(self.deprecating_elements.keys())
-                result['lastGarbageCollection'] = self.last_garbage_collection_time
+                result['deprecationGroupNames'] = list(
+                    self.deprecating_elements.keys())
+                result[
+                    'lastGarbageCollection'] = self.last_garbage_collection_time
             return result
 
     def _get_global_name(self, folder_name, rel_name):
