@@ -11,7 +11,8 @@ class DataStagService(Blueprint):
         """
         Initializer
         """
-        super().__init__("DataStag", __name__, template_folder="./templates", static_folder="./static")
+        super().__init__("DataStag", __name__, template_folder="./templates",
+                         static_folder="./static")
         self.command_handler = DataStagCommandHandler(local=True)
         'The wrapper from http commands to vault commands'
 
@@ -22,15 +23,17 @@ data_stag_service = DataStagService()
 @data_stag_service.route("/run", methods=["POST"])
 def handle_run():
     """
-    Execution function. Converts all commands provided as a JSON object or list of JSON object to local Vault
-    commands and returns their data
+    Execution function. Converts all commands provided as a JSON object or list
+    of JSON object to local Vault commands and returns their data
     """
     try:
         json_data = request.get_json()
         if json_data is not None:
-            result = data_stag_service.command_handler.handle_command_data(json_data)
+            result = data_stag_service.command_handler.handle_command_data(
+                json_data)
             return jsonify(result)
         current_app.logger.error("No data provided to DataStag call")
         return jsonify({})
     except:
-        current_app.logger.error("An error occurred during the execution of a DataStag request")
+        current_app.logger.error(
+            "An error occurred during the execution of a DataStag request")
