@@ -1,6 +1,7 @@
 """
-Simple demo which loads an image from Wikipedia using WebStag, loads it via ImageStag and displays it in a TKInter
-window. In addition it applies a classic OpenCv2 filter
+Simple demo which loads an image from the web using WebStag, loads it via
+ImageStag and displays it in a TKInter window. In addition it applies a
+classic OpenCv2 filter
 """
 
 from tkinter import Tk, Label
@@ -13,7 +14,7 @@ from scistag.tests import TestConstants
 def main():
     root = Tk()
     root.title("ImageStag + WebStag demo")
-    # fetch image from Wikipedia
+    # fetch image from the web
     image = Image(web_fetch(TestConstants.STAG_URL))
     # the original image
     img = ImageTk.PhotoImage(image.to_pil())
