@@ -8,7 +8,7 @@ class CropFilter(ImageFilter):
     Crops a selected region out of an image
     """
 
-    def __init__(self, box: Tuple[int, int, int, int]):
+    def __init__(self, box: tuple[int, int, int, int]):
         """
         Initializer
 
@@ -20,4 +20,4 @@ class CropFilter(ImageFilter):
 
     def _apply_filter(self, input_data: dict) -> dict:
         image: Image = input_data[IMAGE_FILTER_IMAGE]
-        return {IMAGE_FILTER_IMAGE: image.crop(self.box)}
+        return {IMAGE_FILTER_IMAGE: image.cropped(self.box)}
